@@ -30,7 +30,7 @@
 
 #define QT_FEATURE_cxx2c -1
 
-#define QT_FEATURE_reduce_relocations 1
+#define QT_FEATURE_reduce_relocations -1
 
 #define QT_FEATURE_signaling_nan 1
 
@@ -59,19 +59,18 @@
 #define QT_FEATURE_test_gui 1
 
 
-#define QT_VERSION_STR "6.9.3"
+#define QT_VERSION_STR "6.10.0"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 9
+#define QT_VERSION_MINOR 10
 
-#define QT_VERSION_PATCH 3
+#define QT_VERSION_PATCH 0
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_MAC_FRAMEWORK_BUILD
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
-#define QT_REDUCE_RELOCATIONS
 #define QT_COMPILER_SUPPORTS_SSE2 1
 #define QT_COMPILER_SUPPORTS_SSE3 1
 #define QT_COMPILER_SUPPORTS_SSSE3 1
